# ATLaSUI - user documentation

__Address of ATLaSUI (BigBrain1 pre-selected):__ [link](http://medpc076.ime.kfa-juelich.de:5001/microdraw/microdraw.html?source=data/brainmap/B20.json)

## What is ATLaSUI?

*ATLaSUI* (Automatic Tissue Labeling System UI) is a web application that allows users to automatically create segmentations of cytoarchitectonic areas using a deep learning algorithm. 
It allows the import of existing annotations or the creation of new annotations, and feed these annotations as training data to multiple deep neural network models.
If all goes well, the trained neural network models are able to automatically identify the respective brain area in other sections, essentially "filling the gaps" between manually created annotations.
This workflow thus allows to map brain areas across large series of sections, which can serve as basis for 3D reconstruction or dense analysis.

## How does it work? - An overview

The following points detail a typical workflow of using ATLaSUI.
The points intent to give a high-level overview of the steps, which are further detailed in the remainder of this documentation.

1. Create a user account for the web page.
2. Import annotations into the user account. Annotations can be imported from [Online Section Tracer (OST)](https://jubrain.fz-juelich.de/apps/sectiontracer/sectiontracer.php) or from [Microdraw](http://ime262.ime.kfa-juelich.de:3000/data?source=http://ime262.ime.kfa-juelich.de/microdraw/data/brainmap/B20.json). Alternatively, annotations can be created directly in ATLaSUI.
3. Define project and tasks. Each task correspond to one trained deep neural network model, and holds annotations to be used for training. Projects group tasks that are related to each other (e.g., regarding similar brain regions).
4. Run training and prediction jobs to train neural network models on the created tasks. 
5. Inspect the prediction results and note down the quality of the created predictions per section.
6. (optional) If the results are not satisfactory, repeat steps 2-5 by providing more annotations and training more neural network models.
7. (optional, currently BigBrain1 only) Send the results of your quality control to Christian Schiffer to attempt a 3D reconstruction of the segmented areas.

[This video](./atlasui_demo.mp4) demonstrates the use of the website.

## Pre-requisites

The following pre-requisites have to be met to enable use of ATLaSUI: 

- __FZJ VPN access__ ATLaSUI displays sensible data and accesses restricted compute infrastructure. For this reason, ATLaSUI is currently only accessible while connected to the VPN of Research Centre Jülich, or from within the JuNet. If you don't have VPN access already, please coordinate with your contact person at FZJ to learn how you can apply for VPN access. Note that external mail addresses require special approval be the IT services. Contact the INM-1 secretaries to get the approval.
- __ATLaSUI user account__ All data used and created by ATLaSUI is associated with a user account. You can simply create a user account yourself by clicking `Log in` in the top left corner of the page, then click `Register` at the bottom of the popup window. Enter a username, your mail, and select a password. The username should reflect who you are, and can include information about the project you are working on (e.g., `cschiffer_visual_system`). Note down your username, as you will need it to log in and for importing annotations. __Note:__ Please note down your password safely, as there is currently no way to recover lost passwords!
- __Annotations__ ATLaSUI is integrated into a modified version of the visualization and annotation tool *Microdraw*, so it is possible to create annotations directly in ATLaSUI. However, it is more common to already have annotations available in a different tool, which are then imported into ATLaSUI. The following import options are currently available:
   - __Importing from standard Microdraw__ Annotations created in the [standard Microdraw](http://ime262.ime.kfa-juelich.de:3000/data?source=http://ime262.ime.kfa-juelich.de/microdraw/data/brainmap/B20.json) of the INM-1 can be imported. Please contact Christian Schiffer to trigger the import. __Specify the username to import annotations from, and the username to import annotations to!__
   - __Importing from Online Section Tracer (OST)__ Annotations created in the [Online Section Tracer (OST)](https://jubrain.fz-juelich.de/apps/sectiontracer/sectiontracer.php) can be imported in a similar fashion. Please contact Christian Schiffer to trigger the import. __Specify the OST project to import annotations from, and the username to import annotations to!__ Data from multiple projects can be imported into the same ATLaSUI account. __Note:__ Since OST handles image resolution slightly different than ATLaSUI and Microdraw. As a result, annotations for some brain sections cannot be imported into ATLaSUI. If applicable for a project, these annotations have to be re-created in ATLaSUI using the provided annotation tools.
   - __Importing from Offline Section Tracer XML files (deprecated)__ It is possible to import XML files exported form offline section tracer. To do so, send the XML files to Christian Schiffer, and specify the username to import the annotations to.
   - __Annotating in ATLaSUI__ When annotating in ATLaSUI directly, please stick to the naming scheme known from OST: `NAME_l_0`, where `l` can be `l` or `r` and `0` can be a number. Avoid adding additional parts to the name. It is important to know that ATLaSUI identifies areas by their name (capitalization does not matter). Areas with different names are considered as different areas, leading to incorrect results!

## Core concepts 

The segmentation method implemented in ATLaSUI follows a relatively simple idea:
A user annotates one or several brain regions in a set of sections.
These annotations are used to train neural networks, which then segment all sections in-between the annotated sections.
Although this principle is identical for all use cases, there are some questions that have to be answered depending on the area:

### How to subdivide the section range?

Consider we want to segment an area (or multiple) in sections 1-1000, where sections 1,100,200,...,900,1000 are annotated.
We can 
1. use all sections to train one model, so the model is trained on 1,100,200,...,900,1000, or
2. we can subdivide the range into (usually equally sized) intervals. In this case, we train one model on 1 & 100, a second model on 100 & 200, ..., and the final model on 900 & 1000.

The first method is suggested if the structure is small and/or has a relatively regular shape and structure across the entire extent.
For example, nuclei with a round or almond-shaped structure have turned out to be nicely segmented using a single model.
In comparison, areas that vary a lot in microstructure and/or morphology (e.g., most cortical areas) are typically better segmented using the interval approach.

Note that the above assumes equally sized intervals, but this is not required.
For example, it has turned out to be beneficial in many cases to use wide intervals in the center of an area (along the cutting direction), but a finer interval towards the boundaries.

If in doubt, it is recommended to start with the simpler approach (one model for all), and increase the complexity (using intervals) if necessary.

__Tip:__ The task wizard supports users in automatically creating tasks at certain intervals. 

### How to subdivide multiple areas?

Consider you are interested in brain areas A, B, and C.
Similar to the section subdivision, you have multiple options to handle the areas:

1. Train one model to segment areas A, B, and C, or
2. Train one model for each area, meaning one model for A, one model for B, and one model for C.

Again, it is advisable to start with the simple approach of training one model for all considered areas, and go for the more complex approach if the first approach does not yield good results.
Note that the subdivision of sections and areas can be freely combined, e.g.,

1. Training one model for all sections and all areas.
2. Train one model for each section interval and all areas.
3. Training models for all sections, but one model per areas. 
4. Train one model per section interval and area.

The above cases increase in complexity.
It is usually a good approach to start with the simplest (top) and progress towards the more complex ones (bottom) only when necessary.
Note that mixing approaches is always possible, as described in the previous section about intervals with varying depth.

<img src="./intervals_schematic.png" width="400pt"></img>  
*Example use case for training deep learning models. This example shows the last case indicated above: Models are trained for each section interval, and for one specific area.*

## Using ATLaS

This section assumes that you have an idea how you want to approach the segmentation of the areas you are interested.
We will now detail how to use ATLaSUI to define these tasks.

### Start 

1. Navigate to the [website](http://medpc076.ime.kfa-juelich.de:5001/microdraw/microdraw.html?source=data/brainmap/B20.json).
2. Click the `Log in button` at the top left corner. If not already registered, do so. Remember your username and password.
3. When logged in, click the blue `ATLaS UI` button in the left toolbar. This will open the ATLaSUI main menu.

### Creating a project

The next step is to create a project.
A project can contain multiple tasks, and each task corresponds to one neural network training.
Projects can be particularly useful if you want to try different subdivision approaches, or if you want to work with different areas independently.

1. To create a project, click the `New project...` button in the ATLaSUI main menu. The project dialogue opens.
2. Enter a name for the project. The brain identifier usually does not need to be changed.
3. Click `Save` at the bottom row.
4. The project now shows up in the ATLaSUI main menu. It can be edited using the `Edit` button, or deleted using the `Delete` button. The project gets an ID. Please specify this ID when requesting support.
5. Now click `Edit` to add some tasks to the created project.

### Creating tasks

Projects contain tasks.
Each task corresponds to a neural network model that is trained to perform segmentation of one or multiple brain areas (see "Core concepts" sections).
The suggested way to create tasks is the `Task wizard`. Open it using the green `Task wizard` button in the lower left corner of a project's menu.
__Note:__ Loading of the task wizard can take a while, be patient.

The task wizard assists you in creating many tasks in an automated fashion.
The left `Sections` pane shows the brain sections for which annotations exist in your account (note: should the pane be empty, check that you logged in, and try to close and re-open the task wizard).
By default, none of the available sections are selected, indicated by the red color of the section buttons. Clicking on one of the section buttons enables a section.
The buttons `Enable all` and `Disable all` can be used to enable or disable all sections at the same time, respectively.

When a section is selected, annotations found for this section are added to the `Annotations` pane in the center of the dialogue.
Each annotation is represented by a section number, its name, and a `+` button, allowing to add the annotation to a task.
The `Annotation filter` field at the bottom can be used to filter annotations, for example to only take specific brain areas or a single hemisphere into account.
The field supports [regular expressions](https://en.wikipedia.org/wiki/Regular_expression), allowing very fine-grained selection of annotations.
The website [regex101](https://regex101.com/) is a useful tool to test and learn regular expressions.

The right pane is subdivided into two sections:
The upper part shows the current task, i.e., the task that is currently being defined.
You can give the task a name, and add annotations to the task by clicking the `+` button next to annotations.
Alternatively (and recommended), you can click `Add annotations` to add all currently visible annotations to the current task.
In this way, you can use the filtering ability of the `Sections` and `Annotations` panes to filter the annotations you are interested in, and simply click `Add annotations` to create a task from them.

The checkboxes below the task name further ease task creation.
`Enable auto-rename` automatically removes suffixes from annotation names, typically an indicator of the hemisphere (i.e., `_l` or `_r`) and/or an index (e.g., `_0` or `_1`).
It is important to remove these parts of the annotation names when adding them to a task, because brain regions are defined by their name.
For example, two annotations called `hOc1_l` and `hOc1_r` will be treated as different areas due to their different names, which is most likely undesirable.
Keeping `Enable auto-rename` enabled will ensure that most common suffixes are automatically removed when adding annotations.
In cases that cannot be handled by this feature, you can (and have to) rename the annotations manually in the `Annotations` pane.

The `No auxiliary labels` flag determines whether the segmentation task should include so called auxiliary labels, i.e., cortex and white matter.
As a rule of thumb, isocortical areas should leave the box disabled, while subcortical structures should enable this flag.
Ask for support if you are unsure about this flag.

`Name by sections` is useful to automatically name tasks based on the sections that are included in the contained annotations.
This saves you the time of manually entering the name of the task.
It is recommended to enable this flag for easy task creation, in particular when using different intervals.
Note that this flag has to be enabled before adding annotations to take effect.

After adding annotations and defining a name for the task, use the `Save task` button to add the task to the `Tasks` pane in the bottom right.
After doing so, the current task will be cleared, and you can continue with creating new tasks.
When you are finished creating tasks, click the `Save` button to add the created tasks to the project.

#### The `Import` feature

Creating many tasks can be tedious, especially for many intervals.
The `Import` button in the lower left corner opens a text window, which allows you to easily define intervals.
For example, the following text will automatically create three tasks, one for each of the given intervals.

```bash
100-200
200-300
300-400
```

It is important to note that the `Import` feature only works if a filter is specified in the `Task wizard`.
This is a safety measure to prevent accidentally add incorrect annotations.
Use the filter `.*` to force add all annotations, independent of their name (typically not recommended).

### Starting training jobs 

After creating tasks, it is time to actually start the training of the neural network models for segmentation.
During training, the neural network learns the structure of selected area(s) from the provided annotations, so it can later be used to automatically segment new brain sections.
The easiest way to start the training and prediction this is by clicking the `Train+Predict all` button in the project menu.
This will start training and prediction jobs on the HPC system JURECA-DC (JSC, Jülich).

It is important to note that submitted jobs do not necessarily start immediately.
Depending on the load of the HPC system, jobs may take some time to start.
You can check the status of submitted jobs by clicking on the `Jobs` button next to a task.
There, you will see a list of submitted jobs, as well as their state.
Jobs can be `Pending`, `Running`, `Completed`, or `Failed`.
If a job is pending or running, you need to wait until the job is finished.
Typically, training takes between 10 and 20 minutes, while prediction can take between a few minutes up to two hours, depending on how many sections are being predicted.
If both training and prediction jobs are completed, predictions are ready to be viewed.
If a job fails, ask for support. 

__Note:__ The system only provides status information for the most recent jobs.
Jobs that finished too long ago will have the status `Unknown`.
In case you see this status, assume that the job finished successfully, if you do not receive a mail that tells you otherwise.
If a job has unknown status, and you have problems viewing the results, ask for support.

### Viewing results

Prediction results can be inspected for each task by clicking on the clipboard icon next to each task.
Clicking on this button will open a new tab with a new microdraw page.
Navigate to the sections with predictions available to view the segmentation results as overlay.
Use the slider on the left to control the opacity of the overlay.

Segmentations are available for all sections in-between the annotated sections.
For example, if a task uses annotations on sections 200 and 300, segmentations will be created for sections 200 to 300.

## What's next?

After you obtained predictions, the next step is to quality check the predictions.
View them and try to find out if the prediction results are satisfactory.
If not, consider trying a different approach for subdividing sections and areas (see "Core concepts" section).

If results are satisfactory, a possible next step is attempting a 3D reconstruction.
Currently, this is only possible for the BigBrain dataset.
The prerequisite for the 3D reconstruction is a systematic quality check of the predictions.
The quality check consists of a classification of the section into "good" or "bad" segmentations.
It is important to note that not all segmentations need to be of good quality to obtain a good reconstruction.
As long as there is a sufficient amount of good quality segmentations, the 3D reconstruction can be created by interpolating between good segmentations.

In practice, the quality check is performed by filling a simple excel table.
You should use the template provided [here](./classification.xlsx).
Create the relevant section range in the first column, and classify each section by entering "0" for bad quality and "1" for good quality.
If you are unsure about individual sections, ask for support.
Repeat the classification for each project you want to create a reconstruction for.  
__Important:__ Do not modify the structure of the table, and do not enter additional information. Only use "0" and "1" for classification. Any other information may prevent automatic processing and will slow down the reconstruction process.

When you are finished with the classification, send the classification file to Christian Schiffer, so he can attempt a reconstruction.
Please include the following information in your request.

- The filled out quality check table.
- The ID (__not__ the name!) of the project to pull annotations from. 
- If not all tasks of a project should be used, a comma separated list of task IDs to use (e.g., "1,2,3,5,6,10").
- A comma separated list of areas to consider for reconstruction (e.g., "hOc1,hOc2,hOc5").

## FAQ

### Q: Where can I find ATLaSUI?

A: ATLaSUI is currently hosted [here](http://medpc076.ime.kfa-juelich.de:5001/microdraw/microdraw.html?source=data/brainmap/B20.json).
Note that this URL shows the BigBrain dataset by default.
If you want to use different datasets, please contact Christian Schiffer to receive an appropriate URL.

### Q: Who is responsible for ATLaSUI? 

A: ATLaSUI is developed, maintained, and supported by Christian Schiffer (c.schiffer@fz-juelich.de).
